@@ -15,7 +15,7 @@ testthat::test_that("util_eval", {
 
 
   ## Now we check if we can run a simple simulation:
-  ## Step1: Create a nl obejct:
+  ## Step1: Create a nl object:
   modelpath <- file.path(nlpath, "app", "models", "Sample Models",
                          "Biology", "Wolf Sheep Predation.nlogo")
 
@@ -313,4 +313,23 @@ testthat::test_that("util_eval", {
 
   testthat::expect_true(is.null(util_eval_simdesign(nl)))
 
+
+  ## Test eval_simoutput() with empty simoutput
+  nl <- nl()
+  testthat::expect_error(eval_simoutput(nl))
+
+  ## Test eval_simoutput() with results
+  nl <- nl_lhs
+  testthat::expect_equal(nrow(eval_simoutput(nl)), 0)
+
+  ## Test eval_simoutput() with results and removed data
+  nl <- nl_lhs
+  setsim(nl, "simoutput") <- nl@simdesign@simoutput[-1,]
+  testthat::expect_equal(nrow(eval_simoutput(nl)), 1)
+
+  ## Test eval_simoutput() with gensa data
+  nl <- nl_gensa
+  testthat::expect_error(eval_simoutput(nl))
+
+
 })
